@@ -32,13 +32,14 @@ DEFUN(__flock, (fd, operation), int fd AND int operation)
   int cmd;
 
 #ifdef __linux__
+  int errno_saved = errno;
   /* We try the system call first. */
   cmd = __syscall_flock (fd, operation);
   if (cmd == 0 || (cmd < 0 && errno != ENOSYS))
   {
     return cmd;
   }
-  errno = 0;
+  errno = errno_saved;
 #endif
 
   switch (operation & ~LOCK_NB) {
